@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 132 $
+# Revision: $Rev: 137 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -23,7 +23,7 @@
 
 #-- imports --------------------------------------------------------------------
 #-- Qt imports
-from qt import SIGNAL, QListView, QListViewItem, QSize, QTimer
+from qt import SIGNAL, QListView, QSize, QTimer
 from qt import PYSIGNAL, QApplication
 
 
@@ -37,6 +37,7 @@ from types import ListType
 from Settings import getPreferences
 from AbstractFile import AbstractFileRecord
 from misc import Date2YMD
+from lmcqt import ListViewSort
 
 
 #-- preferences ----------------------------------------------------------------
@@ -160,7 +161,8 @@ class ListViewRecord(QListView):
             # all other fields: if no parent exists yet
             if (not self.groupMap.has_key(value)):
                 self.log.debug("Creating parent group %s", value)
-                parent = QListViewItem(self, value, "(1)")
+#                parent = QListViewItem(self, value, "(1)")
+                parent = ListViewSort(self, value, "(1)")
                 parent.setSelectable(False)
                 self.groupMap[value] = parent
 
@@ -187,7 +189,8 @@ class ListViewRecord(QListView):
             if (not isinstance(r, AbstractFileRecord)):
                 raise(TypeError("Record not instance of AbstractFileRecord"))
             parent = self.parentGroup(r)
-            obj = QListViewItem(parent, *self.compileTitles(r) )
+#            obj = QListViewItem(parent, *self.compileTitles(r) )
+            obj = ListViewSort(parent, *self.compileTitles(r) )
             obj.setRenameEnabled(0, True)
             self.items[obj] = r
         # keep track of last item added
