@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 105 $
+# Revision: $Rev: 107 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -201,9 +201,11 @@ class Tcprobe(MediaInfo):
         if ((tmp != None) and (self.audioFormat != "")):
             self.audioFormat += " VBR"
 
-        tmp = self.regexSearch('-e \d+,\d+,\d+ \[(\d+),(\d+),(\d+)\] ', text, None)
-        if (tmp and (len(tmp) == 3) and (self.audioFormat != "")):
-            self.audioFormat += " (freq=%s, bits=%s, ch=%s)"%tmp
+# this is always there if an audio codec was detected; comment out for now
+# remove completely later
+#         tmp = self.regexSearch('-e \d+,\d+,\d+ \[(\d+),(\d+),(\d+)\] ', text, None)
+#         if (tmp and (len(tmp) == 3) and (self.audioFormat != "")):
+#             self.audioFormat += " (freq=%s, bits=%s, ch=%s)"%tmp
             
         tmp = self.regexSearch('-g (\d+x\d+)', text, "no match for resolution")
         if (tmp): self.resolution = tmp[0]
@@ -251,7 +253,7 @@ if (__name__ == "__main__"):
 
 #    QMessageBox.information(None, "scanning file...", "Scanning file...")
     
-    query = Tcprobe(filename4)
+    query = Tcprobe(filename3)
     query.scan()
     print query
 
