@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 114 $
+# Revision: $Rev: 128 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -87,6 +87,10 @@ class RecordList(RecordListBase):
         imageLayout = QGridLayout( self.frameImage, 1,1 )
         imageLayout.addWidget( self.image, 0,0 )
 
+        # grouping
+        self.currentGroup = None
+
+        # connect signals
         self.connect( self.listViewRecord, SIGNAL("currentChanged(QListViewItem*)"), self.onCurrentChanged )
         self.connect( self.listViewRecord, PYSIGNAL("searchTextChanged"), PYSIGNAL("searchTextChanged"))
         self.connect( self.form, PYSIGNAL("modified()"), self.listViewRecord.onModified )    
@@ -124,7 +128,7 @@ class RecordList(RecordListBase):
         return self.listViewRecord.getCurrentRecord()
 
 
-    def setCurrentRecord(self, record):        
+    def setCurrentRecord(self, record):
         self.listViewRecord.setCurrentRecord(record)
         self.form.setRecord(record)
         self.image.setRecord(record)
@@ -134,13 +138,29 @@ class RecordList(RecordListBase):
         self.listViewRecord.findNext(text, field, options)
 
 
-    #-- observer ---------------------------------------------------------------
+    #-- slots ------------------------------------------------------------------
+    def onGroup(self, group):
+        """called when an online re-grouping is necessary"""
+        if (group != self.currentGroup):
+            self.currentGroup = group
+            self.disconnect(self.listViewRecord, SIGNAL("currentChanged(QListViewItem*)"), self.onCurrentChanged)
+            self.listViewRecord.onGroup(group)
+            self.connect(self.listViewRecord, SIGNAL("currentChanged(QListViewItem*)"), self.onCurrentChanged)
+            self.focus(self.listViewRecord.currentItem())
+        
+
     def onCurrentChanged(self, obj):
         """called when the \"current\" item changes"""
         if (obj != None):
             record = self.listViewRecord.getCurrentRecord()
-            self.form.setRecord( record )
-            self.image.setRecord( record )
+            if (record == None):
+                if (not self.form.isHidden()): self.form.hide()
+                if (not self.image.isHidden()): self.image.hide()
+            else:
+                if (self.form.isHidden()): self.form.show()
+                self.form.setRecord( record )
+                if (self.image.isHidden()): self.image.show()
+                self.image.setRecord( record )
         else:
             self.form.setRecord(None)
             self.image.setRecord(None)
