@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 114 $
+# Revision: $Rev: 132 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -39,6 +39,19 @@ from os.path import dirname, basename, exists as fexists, samefile, \
      getsize as fsize, splitext, join as fjoin
 from copy import deepcopy
 
+
+#-- create logging and load preferences ----------------------------------------
+log = logging.getLogger("")
+hdlr = logging.StreamHandler()
+formatter = logging.Formatter('[%(name)s] %(levelname)s: %(message)s')
+hdlr.setFormatter(formatter)
+log.addHandler(hdlr) 
+log.setLevel(logging.DEBUG)             # default log level
+
+# output program text-logo
+log.info("lmc.py - LMC Movie Catalogue  $Rev: 132 $ (c) by Uwe Mayer")
+
+
 #-- own imports --
 import Settings
 import MediaInfo
@@ -55,18 +68,9 @@ from ScriptExecDialog import ScriptExecDialog
 from ScriptSelection import ScriptSelection
 from StdIOProcess import StdIOProcess
 from FindDialog import FindDialog
+from CatalogueProperties import CatalogueProperties
 
 
-#-- create logging and load preferences ----------------------------------------
-log = logging.getLogger("")
-hdlr = logging.StreamHandler()
-formatter = logging.Formatter('[%(name)s] %(levelname)s: %(message)s')
-hdlr.setFormatter(formatter)
-log.addHandler(hdlr) 
-log.setLevel(logging.DEBUG)             # default log level
-
-# output program text-logo
-log.info("lmc.py - LMC Movie Catalogue  $Rev: 114 $ (c) by Uwe Mayer")
 
 # load settings
 settings = Settings.Settings()
@@ -108,7 +112,7 @@ fileFilterList = filter(lambda a: a != "", map(lambda a: a[1], fileFormats))
 
 
 #-- utility functions ----------------------------------------------------------
-defaultCaption = "Moviefly ($Rev: 114 $) "
+defaultCaption = "Moviefly ($Rev: 132 $) "
 filenameCaption = lambda a: defaultCaption+" - %s"%basename(a)
 
 
@@ -134,6 +138,35 @@ class LMCMain(LMCWidgetBase):
         # add popup menu
         self.toolGetFromFilesAction.setPopup(self.movieGetLocalPopup)
 
+        # grouping popup menu
+        self.groupPopup = QPopupMenu(self)
+        self.groupPopup.insertItem(self.tr("no grouping"), self.movieGroup)
+        self.groupPopup.insertSeparator()
+        self.groupPopup.insertItem(self.tr("by rating"), self.movieGroup)
+        self.groupPopup.insertItem(self.tr("by year"), self.movieGroup)
+        self.groupPopup.insertItem(self.tr("by source"), self.movieGroup)
+        self.groupPopup.insertItem(self.tr("by borrower"), self.movieGroup)
+        self.groupPopup.insertItem(self.tr("by country"), self.movieGroup)
+        self.groupPopup.insertItem(self.tr("by category"), self.movieGroup)
+        self.groupPopup.insertItem(self.tr("by length"), self.movieGroup)
+        self.groupPopup.insertItem(self.tr("by languages"), self.movieGroup)
+        self.groupPopup.insertItem(self.tr("by date added"), self.movieGroup)
+        
+        # remember id->type
+        self.groupType = dict()
+        self.groupType[self.groupPopup.idAt(0)] = None
+        self.groupType[self.groupPopup.idAt(2)] = 'rating'
+        self.groupType[self.groupPopup.idAt(3)] = 'year'
+        self.groupType[self.groupPopup.idAt(4)] = 'source'
+        self.groupType[self.groupPopup.idAt(5)] = 'borrower'
+        self.groupType[self.groupPopup.idAt(6)] = 'country'
+        self.groupType[self.groupPopup.idAt(7)] = 'category'
+        self.groupType[self.groupPopup.idAt(8)] = 'length'
+        self.groupType[self.groupPopup.idAt(9)] = 'languages'
+        self.groupType[self.groupPopup.idAt(10)] = 'date'
+        # add popup menu
+        self.toolGroupAction.setPopup(self.groupPopup)
+
         # runtime variables
         self.__file = None              # no file opened so far
         self.lastFolder = pref['defaultPath']
@@ -155,6 +188,14 @@ class LMCMain(LMCWidgetBase):
         self.connect(self.toolNewAction, SIGNAL("pressed()"), self.fileNew)
         self.toolNewAction.setEnabled(True)
 
+        # auto-open
+        if (pref['defaultFile'] != None):
+            self.log.info("Opening default file %s", basename(pref['defaultFile']))
+            if (not fexists(pref['defaultFile'])):
+                self.log.warning("Cannot open file %s; file does not exist", basename(pref['defaultFile']))
+            else:
+                self.fileOpen(pref['defaultFile'])
+
 
 
     #-- slot implementations ---------------------------------------------------
@@ -245,7 +286,7 @@ class LMCMain(LMCWidgetBase):
         # test if file already exists
         if (fexists(filename)):
             ans = QMessageBox.question(self, self.tr("File already exists"),
-                                       self.tr("File already exis. Overwrite?"),
+                                       self.tr("File already exists. Overwrite?"),
                                        QMessageBox.Yes, QMessageBox.No)
             if (ans == QMessageBox.No): return           
 
@@ -331,19 +372,22 @@ class LMCMain(LMCWidgetBase):
         self.__enableSaveCloseActions()
 
 
-
-    def fileOpen(self):
+    def fileOpen(self, defaultFile=None):
         """handles the open-existing-file process"""
         # query save when records dirty
         self.__querySaveOnDirty()
+
+        # no default open given: load from dialog
+        if (defaultFile == None):
+            # create file dialog and get filename
+            dlg = QFileDialog(self.lastFolder, u";;".join(fileFilterList)+ALL_FILES_FILTER, self)
+            dlg.setCaption(self.tr("Open a new file"))
+            dlg.setViewMode(QFileDialog.Detail)
         
-        # create file dialog and get filename
-        dlg = QFileDialog(self.lastFolder, u";;".join(fileFilterList)+ALL_FILES_FILTER, self)
-        dlg.setCaption(self.tr("Open a new file"))
-        dlg.setViewMode(QFileDialog.Detail)
-        
-        if (dlg.exec_loop() == QFileDialog.Rejected): return
-        filename = unicode(dlg.selectedFile())
+            if (dlg.exec_loop() == QFileDialog.Rejected): return
+            filename = unicode(dlg.selectedFile())
+        else:
+            filename = defaultFile
 
         # autoprobe file formats (they raise TypeError on mismatch)
         self.infoStatusBar("Opening file %s"%basename(filename))
@@ -399,6 +443,15 @@ class LMCMain(LMCWidgetBase):
             self.__enableMovieDeleteAction()
 
 
+    def fileProperties(self):
+        """display catalogue properties"""
+        dlg = CatalogueProperties(self.__file)
+        if ((dlg.exec_loop() == dlg.Accepted) and dlg.modified):
+            self.log.info("Saving file meta-data")
+            self.infoStatusBar("Saving file meta-data")
+            self.__file.flush()
+    
+
     def movieAdd(self):
         """adds a new movie record"""
         # scan for the first available index number
@@ -471,7 +524,7 @@ class LMCMain(LMCWidgetBase):
 
         # get media info
         self.log.info("Getting file information for %s using %s", basename(filenames[0]), pref['mediaInfo'])
-        self.infoStatusBar("Getting file information from %s"%basename(filename))
+        self.infoStatusBar("Getting file information from %s"%basename(filenames[0]))
         info = pref['mediaInfo'](filenames[0])
         info.scan()
 
@@ -702,7 +755,6 @@ class LMCMain(LMCWidgetBase):
         """find a movie according to field value"""
 
         def findNext(text, field, options):
-#            self.updateStatusBar("Searching for %s in field %s"%(text, field))
             self.centralWidget().findNext(text, field, options)
             
         findDlg = FindDialog(self)
@@ -712,8 +764,17 @@ class LMCMain(LMCWidgetBase):
         self.disconnect(findDlg, PYSIGNAL("findValue"), findNext)
 
 
+    def movieGroup(self, groupId=None):
+        """called when an online re-grouping is necessary"""
+        # get *what* to group by
+        if (groupId != None):
+            groupId = self.groupType[groupId]
+
+        # call responsible function
+        self.centralWidget().onGroup(groupId)
         
 
+
     #-- helper methods ---------------------------------------------------------
     def __querySaveOnDirty(self):
         """asks user wether to save file when there are dirty records"""
@@ -790,6 +851,9 @@ class LMCMain(LMCWidgetBase):
         self.connect(self.toolAddAction, SIGNAL("pressed()"), self.movieAdd)
         self.toolAddAction.setEnabled(True)
 
+        self.connect(self.filePropertiesAction, SIGNAL("activated()"), self.fileProperties)
+        self.filePropertiesAction.setEnabled(True)
+
 
     def __disableSaveCloseActions(self):
         """disables Save, SaveAs and Close actions"""
@@ -820,6 +884,9 @@ class LMCMain(LMCWidgetBase):
             self.toolPasteAction.setEnabled(False)
             self.disconnect(self.toolPasteAction, SIGNAL("pressed()"), self.moviePaste)
 
+        self.filePropertiesAction.setEnabled(False)
+        self.disconnect(self.filePropertiesAction, SIGNAL("activated()"), self.fileProperties)
+
 
     def __enableMovieDeleteAction(self):
         """enables actions related to deleting a record"""
@@ -862,6 +929,10 @@ class LMCMain(LMCWidgetBase):
         self.connect(self.toolFindAction, SIGNAL("pressed()"), self.movieFind)
         self.toolFindAction.setEnabled(True)
 
+        self.connect(self.toolGroupAction, SIGNAL("clicked()"), self.movieGroup)
+        self.toolGroupAction.setEnabled(True)
+        
+
 
     def __disableMovieDeleteAction(self):
         """disables actions related to deleting a record"""
@@ -902,6 +973,9 @@ class LMCMain(LMCWidgetBase):
 
         self.toolFindAction.setEnabled(False)
         self.disconnect(self.toolFindAction, SIGNAL("pressed()"), self.movieFind)
+
+        self.toolGroupAction.setEnabled(False)
+        self.disconnect(self.toolGroupAction, SIGNAL("clicked()"), self.movieGroup)
         
         
 
@@ -911,7 +985,6 @@ app = QApplication(sys.argv)
 QObject.connect(app, SIGNAL("lastWindowClosed()"), app, SLOT("quit()"))
 
 main = LMCMain()
-main.setCaption(defaultCaption)
 
 app.setMainWidget(main)
 main.show()
